=============================
zerial
=============================

.. image:: https://badge.fury.io/py/zerial.png
    :target: http://badge.fury.io/py/zerial

.. image:: https://travis-ci.org/jriddy/zerial.png?branch=master
    :target: https://travis-ci.org/jriddy/zerial

Stuct and destructure complex classes


Features
--------

* TODO

